telegram

package
v0.1.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 3, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateClient

func CreateClient(appID int, appHash, sessionPath, proxyURL string) (*telegram.Client, error)

CreateClient creates a new Telegram client with optional proxy support

func CreateClientWithHandler

func CreateClientWithHandler(appID int, appHash, sessionPath, proxyURL string, handler telegram.UpdateHandler) (*telegram.Client, error)

CreateClientWithHandler creates a new Telegram client with optional proxy and update handler

func CreateDialer

func CreateDialer(proxyURL string) (dcs.DialFunc, error)

CreateDialer creates a dial function with optional proxy support

func ParseProxyURL

func ParseProxyURL(proxyURL string) (*url.URL, error)

ParseProxyURL parses and validates a proxy URL Supported formats:

func TestProxy

func TestProxy(ctx context.Context, proxyURL string) error

TestProxy tests proxy connectivity by attempting to connect to a Telegram DC

Types

This section is empty.

Jump to