Documentation
¶
Index ¶
- func CreateClient(appID int, appHash, sessionPath, proxyURL string) (*telegram.Client, error)
- func CreateClientWithHandler(appID int, appHash, sessionPath, proxyURL string, ...) (*telegram.Client, error)
- func CreateDialer(proxyURL string) (dcs.DialFunc, error)
- func ParseProxyURL(proxyURL string) (*url.URL, error)
- func TestProxy(ctx context.Context, proxyURL string) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateClient ¶
CreateClient creates a new Telegram client with optional proxy support
func CreateClientWithHandler ¶
func CreateClientWithHandler(appID int, appHash, sessionPath, proxyURL string, handler telegram.UpdateHandler) (*telegram.Client, error)
CreateClientWithHandler creates a new Telegram client with optional proxy and update handler
func CreateDialer ¶
CreateDialer creates a dial function with optional proxy support
func ParseProxyURL ¶
ParseProxyURL parses and validates a proxy URL Supported formats:
- socks5://host:port
- socks5://user:pass@host:port
- http://host:port
- http://user:pass@host:port
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.